aboutsummaryrefslogtreecommitdiffstats
path: root/capture.c
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2014-05-23 10:50:02 +0000
committerGuy Harris <guy@alum.mit.edu>2014-05-23 10:50:10 +0000
commita344c9736efe5519543da1290e1ad9065d0b0cff (patch)
tree7757d80d74ae710e5d4e4a1b0cb638d0ec644fc4 /capture.c
parent716fdc8e398ea7435b23192ab1f7d59e7b21e32b (diff)
Revert "Allow wtap_read() and wtap_seek_read() to return non-packet records."
This reverts commit c0c480d08c175eed4524ea9e73ec86298f468cf4. A better way to do this is to have the record type be part of struct wtap_pkthdr; that keeps the metadata for the record together and requires fewer API changes. That is in-progress. Change-Id: Ic558f163a48e2c6d0df7f55e81a35a5e24b53bc6 Reviewed-on: https://code.wireshark.org/review/1741 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'capture.c')
-rw-r--r--capture.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/capture.c b/capture.c
index c7f9ebf995..c308727096 100644
--- a/capture.c
+++ b/capture.c
@@ -390,9 +390,9 @@ capture_input_new_file(capture_session *cap_session, gchar *new_file)
}
/* capture child tells us we have new records to read */
void
-capture_input_new_records(capture_session *cap_session, int to_read)
+capture_input_new_packets(capture_session *cap_session, int to_read)
{
capture_options *capture_opts = cap_session->capture_opts;
int err;
@@ -435,7 +435,7 @@ capture_input_new_records(capture_session *cap_session, int to_read)
#endif
if(capture_opts->show_info)
- capture_info_new_records(to_read);
+ capture_info_new_packets(to_read);
}
@@ -390,9 +390,9 @@ capture_input_new_file(capture_session *cap_session, gchar *new_file)
}
-/* capture child tells us we have new records to read */
+/* capture child tells us we have new packets to read */
void